This function performs minimal cleaning operations on CES data to maximize preservation of variable metadata, including labels and attributes.
clean_ces_data_preserve_metadata(data, year, language = "en")A cleaned tibble with preserved metadata.
A tibble or data.frame containing raw CES data.
A character string indicating the year of the CES data.
A character string indicating the language for labels ("en" or "fr").