show_variant_message: Show variant information message when multiple variants are...

View source: R/platform_utils.R

show_variant_messageR Documentation

Show variant information message when multiple variants are available

Description

This helper function displays an informative message when a user accesses a year with multiple variants without specifying a variant parameter.

Usage

show_variant_message(year, selected_variant, is_variant_null, verbose = TRUE)

Arguments

year

Character string indicating the year

selected_variant

Character string indicating the variant that was selected

is_variant_null

Logical indicating if variant parameter was NULL

verbose

Logical indicating whether to show messages

Value

NULL (invisible), message shown as side effect


ces documentation built on June 7, 2026, 9:08 a.m.